dot-generate_output_dates: Generate output dates for forecast method. This is a private...

.generate_output_datesR Documentation

Generate output dates for forecast method. This is a private function of 'nixtlar'

Description

Generate output dates for forecast method. This is a private function of 'nixtlar'

Usage

.generate_output_dates(df_info, freq, h)

Arguments

df_info

A data frame that is created by the forecast method with the last dates of every unique id.

freq

The frequency of the data, as a period or offset alias.

h

The forecast horizon.

Value

A data frame with dates for the forecast.

Examples

## Not run: 
  dates_df <- .generate_output_dates(df_info, freq, h)

## End(Not run)


nixtlar documentation built on June 23, 2026, 9:06 a.m.