dot-get_client_version: Get the 'nixtlar' client version string This is a private...

.get_client_versionR Documentation

Get the 'nixtlar' client version string This is a private function of 'nixtlar'

Description

Get the 'nixtlar' client version string This is a private function of 'nixtlar'

Usage

.get_client_version()

Value

A character string of the form "R-x.y.z", where x.y.z is the installed 'nixtlar' package version (read from the DESCRIPTION file).

Examples

## Not run: 
  .get_client_version()

## End(Not run)


nixtlar documentation built on June 23, 2026, 9:06 a.m.