dot-transient_errors: A function used by httr2::req_retry() to determine if the...

.transient_errorsR Documentation

A function used by httr2::req_retry() to determine if the response represents a transient error This is a private function of 'nixtlar'

Description

A function used by httr2::req_retry() to determine if the response represents a transient error This is a private function of 'nixtlar'

Usage

.transient_errors(resp)

Arguments

resp

The response to a HTTP request

Value

TRUE if the response status is 500 or 502, FALSE otherwise.

Examples

## Not run: 
.transient_errors(resp)

## End(Not run)


nixtlar documentation built on June 23, 2026, 9:06 a.m.