dot-validate_exogenous: Validate future exogenous variables (if applicable) This is a...

.validate_exogenousR Documentation

Validate future exogenous variables (if applicable) This is a private function of 'nixtlar'

Description

Validate future exogenous variables (if applicable) This is a private function of 'nixtlar'

Usage

.validate_exogenous(df, h, X_df)

Arguments

df

A tsibble or a data frame with time series data.

h

Forecast horizon.

X_df

A tsibble or a data frame with future exogenous variables.

Value

If the validation is successful, the function executes without errors. If the validation fails, it stops execution and returns an error message indicating that the future exogenous variables must cover the forecast horizon.

Examples

## Not run: 
df <- nixtlar::electricity_exo_vars
X_df <- nixtlar::electricity_future_exo_vars
.validate_exogenous(df, h=24, X_df)

## End(Not run)


nixtlar documentation built on June 23, 2026, 9:06 a.m.