| .validate_exogenous | R Documentation |
Validate future exogenous variables (if applicable) This is a private function of 'nixtlar'
.validate_exogenous(df, h, X_df)
df |
A tsibble or a data frame with time series data. |
h |
Forecast horizon. |
X_df |
A tsibble or a data frame with future exogenous variables. |
If the validation is successful, the function executes without errors. If the validation fails, it stops execution and returns an error message indicating that the future exogenous variables must cover the forecast horizon.
## Not run:
df <- nixtlar::electricity_exo_vars
X_df <- nixtlar::electricity_future_exo_vars
.validate_exogenous(df, h=24, X_df)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.